/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.handlers;

import org.wso2.registry.Resource;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.ResourcePath;
import org.wso2.registry.exceptions.RegistryException;

public abstract class UIEnabledHandler extends Handler {

    public Resource get(RequestContext requestContext) throws RegistryException {

        ResourcePath resourcePath = requestContext.getResourcePath();
        if (resourcePath.parameterExists(RegistryConstants.VIEW_PROPERTY)) {
            Resource resource = getView(resourcePath.getParameterValue(RegistryConstants.VIEW_PROPERTY), requestContext);
            resource.setProperty(
                    RegistryConstants.UI_CONTENT_PROPERTY, RegistryConstants.UI_HTML);
            return resource;

        } else if (resourcePath.parameterExists(RegistryConstants.EDIT_PROPERTY)) {
            Resource resource = getEdit(resourcePath.getParameterValue(RegistryConstants.EDIT_PROPERTY), requestContext);
            resource.setProperty(
                    RegistryConstants.UI_CONTENT_PROPERTY, RegistryConstants.UI_HTML);
            return resource;

        } else {
            return getRawResource(requestContext);
        }
    }

    public abstract Resource getRawResource(RequestContext requestContext)
            throws RegistryException;

    public abstract Resource getView(String viewName, RequestContext requestContext)
            throws RegistryException;

    public abstract Resource getEdit(String editName, RequestContext requestContext)
            throws RegistryException;
}
