/*
 * Copyright (c) 2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.jdbc.indexing;

import org.apache.lucene.analysis.standard.StandardAnalyzer;
import org.apache.lucene.document.Document;
import org.apache.lucene.document.Field;
import org.apache.lucene.index.CorruptIndexException;
import org.apache.lucene.index.IndexReader;
import org.apache.lucene.index.IndexWriter;
import org.apache.lucene.index.Term;
import org.apache.lucene.store.RAMDirectory;
import org.wso2.registry.Resource;
import org.wso2.registry.config.RegistryContext;
import org.wso2.registry.exceptions.RegistryException;
import org.wso2.registry.jdbc.dao.ResourceDAO;
import org.wso2.registry.jdbc.handlers.RequestContext;

import java.io.DataInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.sql.SQLException;

public class Indexer {

    public void updateIndex(RequestContext requestContext) throws RegistryException {
        StringBuffer sb = new StringBuffer();
        String line, id;
        ResourceDAO resourceDAO = new ResourceDAO();

        Resource resource = requestContext.getResource();
        String path = requestContext.getResourcePath().getPath();
        RAMDirectory ramDir = RegistryContext.getSingleton().getRamDir();

        try {

            if (resourceDAO.resourceExists(path)) {
                id = resourceDAO.getResourceID(path, RegistryContext.getSingleton().getDataSource().getConnection());
                if (IndexReader.indexExists(ramDir)) {
                    IndexReader reader = IndexReader.open(ramDir);
                    Term term = new Term("id", id);
                    if (reader.docFreq(term) > 0) {
                        reader.deleteDocuments(term);
                    }
                    reader.close();
                }
            } else {
                id = resource.getId();
            }


            byte[] content = (byte[]) resource.getContent();
            String contentString = null;
            if(content != null){
                contentString = new String(content);
            }

            String url = requestContext.getSourceURL();
            if(url != null){
                URL resourceURL = new URL(url);
                InputStream is = resourceURL.openStream();

                DataInputStream din = new DataInputStream(is);
             while((line=din.readLine()) != null){
                 sb.append(line+"\n");
                 contentString = sb.toString();
             }
             is.close();
            }


            Document document = new Document();
            document.add(new Field("id", id, Field.Store.YES, Field.Index.TOKENIZED));
            document.add(new Field("content", contentString, Field.Store.NO, Field.Index.TOKENIZED));

            IndexWriter writer = new IndexWriter(RegistryContext.getSingleton().getRamDir(), new StandardAnalyzer());
            writer.addDocument(document);
            writer.optimize();
            writer.close();
        } catch (CorruptIndexException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } catch (SQLException e) {
            throw new RegistryException(e.getMessage());
        }
    }

    public void deleteFromIndex(RequestContext requestContext) throws RegistryException {
        String id;

        RAMDirectory ramDir = RegistryContext.getSingleton().getRamDir();

        Resource resource = requestContext.getResource();
        id = resource.getId();

        try {
            IndexReader reader = IndexReader.open(ramDir);
            Term term = new Term("id", id);
            if (reader.docFreq(term) > 0) {
                reader.deleteDocuments(term);
            }
            reader.close();
        } catch (CorruptIndexException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }


    }
}
