/*
 * Copyright (c) 2006, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.wso2.registry.web.populators;

import org.wso2.registry.web.beans.ContentBean;
import org.wso2.registry.web.UIConstants;
import org.wso2.registry.web.MediaTypesReader;
import org.wso2.registry.web.utils.CommonUtil;
import org.wso2.registry.Resource;
import org.wso2.registry.Collection;
import org.wso2.registry.RegistryConstants;
import org.wso2.registry.ResourcePath;
import org.wso2.registry.exceptions.RegistryException;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.servlet.http.HttpServletRequest;

public class ContentBeanPopulator {

    private static final Log log = LogFactory.getLog(ContentBeanPopulator.class);

    public static void populate(HttpServletRequest request, Resource resource, ResourcePath path) {

        ContentBean contentBean = new ContentBean();

        contentBean.setCollection(resource instanceof Collection);

        try {
            contentBean.setCollectionTypes(MediaTypesReader.getCollectionMediaTypes(request));
        } catch (RegistryException e) {
            String msg = "Failed to get defined collection media types. " + e.getMessage();
            log.error(msg, e);

            contentBean.setErrorMessage(msg);
            CommonUtil.addErrorMessage(request, msg);
        }

        contentBean.setContentPath(path.getCompletePath());

        String UIAction = null;
        if (path.parameterExists(RegistryConstants.VIEW_ACTION)) {
            UIAction = RegistryConstants.VIEW_PROPERTY;
        } else if (path.parameterExists(RegistryConstants.EDIT_ACTION)) {
            UIAction = RegistryConstants.EDIT_PROPERTY;
        }
        contentBean.setUIAction(UIAction);


        String UIContent = resource.getProperty(RegistryConstants.UI_CONTENT_PROPERTY);
        contentBean.setUIContent(UIContent);

        if (UIContent != null && !RegistryConstants.UI_NONE.equals(UIContent)) {
            try {
                String contentString = (String) resource.getContent();
                contentBean.setContentString(contentString);
            } catch (RegistryException e) {
                String msg = "Failed to get content of the resource " +
                        path + ". " + e.getMessage();
                log.error(msg, e);
                CommonUtil.addErrorMessage(request, msg);
                contentBean.setErrorMessage(msg);
            }
        }
        
        contentBean.setResource(resource);

        request.getSession().setAttribute(UIConstants.RESOURCE_CONTENT_BEAN, contentBean);
    }
}
